Class: Sendmux::Sending::Generated::AttachmentUploadData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Sending::Generated::AttachmentUploadData
- Defined in:
- lib/sendmux_sending_generated/models/attachment_upload_data.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ Object
Temporary attachment ID to use in email attachments.
-
#content_type ⇒ Object
Stored attachment MIME type.
-
#expires_at ⇒ Object
ISO timestamp when this temporary attachment reference expires.
-
#filename ⇒ Object
Stored attachment filename.
-
#size_bytes ⇒ Object
Stored attachment byte size.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachmentUploadData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AttachmentUploadData
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Sending::Generated::AttachmentUploadData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Sending::Generated::AttachmentUploadData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attachment_id') self. = attributes[:'attachment_id'] else self. = nil end if attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] else self.content_type = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'filename') self.filename = attributes[:'filename'] else self.filename = nil end if attributes.key?(:'size_bytes') self.size_bytes = attributes[:'size_bytes'] else self.size_bytes = nil end end |
Instance Attribute Details
#attachment_id ⇒ Object
Temporary attachment ID to use in email attachments.
19 20 21 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 19 def @attachment_id end |
#content_type ⇒ Object
Stored attachment MIME type
22 23 24 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 22 def content_type @content_type end |
#expires_at ⇒ Object
ISO timestamp when this temporary attachment reference expires.
25 26 27 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 25 def expires_at @expires_at end |
#filename ⇒ Object
Stored attachment filename
28 29 30 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 28 def filename @filename end |
#size_bytes ⇒ Object
Stored attachment byte size
31 32 33 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 31 def size_bytes @size_bytes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 34 def self.attribute_map { :'attachment_id' => :'attachment_id', :'content_type' => :'content_type', :'expires_at' => :'expires_at', :'filename' => :'filename', :'size_bytes' => :'size_bytes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 55 def self.openapi_types { :'attachment_id' => :'String', :'content_type' => :'String', :'expires_at' => :'Time', :'filename' => :'String', :'size_bytes' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && content_type == o.content_type && expires_at == o.expires_at && filename == o.filename && size_bytes == o.size_bytes end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 239 def hash [, content_type, expires_at, filename, size_bytes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @attachment_id.nil? invalid_properties.push('invalid value for "attachment_id", attachment_id cannot be nil.') end pattern = Regexp.new(/^att_[a-z0-9]{24}$/) if @attachment_id !~ pattern invalid_properties.push("invalid value for \"attachment_id\", must conform to the pattern #{pattern}.") end if @content_type.nil? invalid_properties.push('invalid value for "content_type", content_type cannot be nil.') end if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @filename.nil? invalid_properties.push('invalid value for "filename", filename cannot be nil.') end if @size_bytes.nil? invalid_properties.push('invalid value for "size_bytes", size_bytes cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_data.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @attachment_id.nil? return false if @attachment_id !~ Regexp.new(/^att_[a-z0-9]{24}$/) return false if @content_type.nil? return false if @expires_at.nil? return false if @filename.nil? return false if @size_bytes.nil? true end |