Class: Sendmux::Sending::Generated::AttachmentUploadIntentRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AttachmentUploadIntentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Sending::Generated::AttachmentUploadIntentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Sending::Generated::AttachmentUploadIntentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  else
    self.filename = nil
  end

  if attributes.key?(:'sha256')
    self.sha256 = attributes[:'sha256']
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end
end

Instance Attribute Details

#content_typeObject

MIME type expected for the upload.



19
20
21
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 19

def content_type
  @content_type
end

#filenameObject

Filename to associate with the uploaded attachment.



22
23
24
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 22

def filename
  @filename
end

#sha256Object

Optional SHA-256 hex digest for the upload bytes.



25
26
27
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 25

def sha256
  @sha256
end

#size_bytesObject

Exact byte size that will be uploaded.



28
29
30
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 28

def size_bytes
  @size_bytes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 31

def self.attribute_map
  {
    :'content_type' => :'content_type',
    :'filename' => :'filename',
    :'sha256' => :'sha256',
    :'size_bytes' => :'size_bytes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 51

def self.openapi_types
  {
    :'content_type' => :'String',
    :'filename' => :'String',
    :'sha256' => :'String',
    :'size_bytes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      content_type == o.content_type &&
      filename == o.filename &&
      sha256 == o.sha256 &&
      size_bytes == o.size_bytes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 234

def hash
  [content_type, filename, sha256, size_bytes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@content_type.nil? && @content_type.to_s.length > 255
    invalid_properties.push('invalid value for "content_type", the character length must be smaller than or equal to 255.')
  end

  if @filename.nil?
    invalid_properties.push('invalid value for "filename", filename cannot be nil.')
  end

  if @filename.to_s.length > 255
    invalid_properties.push('invalid value for "filename", the character length must be smaller than or equal to 255.')
  end

  if @filename.to_s.length < 1
    invalid_properties.push('invalid value for "filename", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-f0-9]{64}$/)
  if !@sha256.nil? && @sha256 !~ pattern
    invalid_properties.push("invalid value for \"sha256\", must conform to the pattern #{pattern}.")
  end

  if @size_bytes.nil?
    invalid_properties.push('invalid value for "size_bytes", size_bytes cannot be nil.')
  end

  if @size_bytes <= 0
    invalid_properties.push('invalid value for "size_bytes", must be greater than 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_request.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@content_type.nil? && @content_type.to_s.length > 255
  return false if @filename.nil?
  return false if @filename.to_s.length > 255
  return false if @filename.to_s.length < 1
  return false if !@sha256.nil? && @sha256 !~ Regexp.new(/^[a-f0-9]{64}$/)
  return false if @size_bytes.nil?
  return false if @size_bytes <= 0
  true
end