Class: Sendmux::Sending::Generated::BatchResultItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_sending_generated/models/batch_result_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BatchResultItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Sending::Generated::BatchResultItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Sending::Generated::BatchResultItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'index')
    self.index = attributes[:'index']
  else
    self.index = nil
  end

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  else
    self.message_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#errorObject

Error details (only if failed)



19
20
21
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 19

def error
  @error
end

#indexObject

Position in the input array



22
23
24
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 22

def index
  @index
end

#message_idObject

Message ID (null if failed)



25
26
27
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 25

def message_id
  @message_id
end

#statusObject

Result status



28
29
30
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 28

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 53

def self.attribute_map
  {
    :'error' => :'error',
    :'index' => :'index',
    :'message_id' => :'message_id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
87
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 83

def self.openapi_nullable
  Set.new([
    :'message_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 73

def self.openapi_types
  {
    :'error' => :'ErrorDetail',
    :'index' => :'Integer',
    :'message_id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      error == o.error &&
      index == o.index &&
      message_id == o.message_id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 211

def hash
  [error, index, message_id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @index.nil?
    invalid_properties.push('invalid value for "index", index cannot be nil.')
  end

  pattern = Regexp.new(/^eml_[a-z0-9]{24}$/)
  if @message_id !~ pattern
    invalid_properties.push("invalid value for \"message_id\", must conform to the pattern #{pattern}.")
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
156
157
158
159
# File 'lib/sendmux_sending_generated/models/batch_result_item.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @index.nil?
  return false if @message_id !~ Regexp.new(/^eml_[a-z0-9]{24}$/)
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["queued", "failed", "unknown_default_open_api"])
  return false unless status_validator.valid?(@status)
  true
end