Class: Sendmux::Sending::Generated::ErrorDetail

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_sending_generated/models/error_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ErrorDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Sending::Generated::ErrorDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Sending::Generated::ErrorDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'doc_url')
    self.doc_url = attributes[:'doc_url']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'param')
    self.param = attributes[:'param']
  end

  if attributes.key?(:'retryable')
    self.retryable = attributes[:'retryable']
  else
    self.retryable = nil
  end
end

Instance Attribute Details

#codeObject

Machine-readable error code



19
20
21
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 19

def code
  @code
end

#doc_urlObject

Link to error documentation



22
23
24
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 22

def doc_url
  @doc_url
end

#errorsObject

Accumulated per-field issues (validation errors)



25
26
27
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 25

def errors
  @errors
end

#messageObject

Human-readable error description



28
29
30
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 28

def message
  @message
end

#paramObject

Parameter that caused the error



31
32
33
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 31

def param
  @param
end

#retryableObject

True when the client may safely retry the same request. 429 and 5xx default true; 4xx default false.



34
35
36
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 34

def retryable
  @retryable
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 37

def self.attribute_map
  {
    :'code' => :'code',
    :'doc_url' => :'doc_url',
    :'errors' => :'errors',
    :'message' => :'message',
    :'param' => :'param',
    :'retryable' => :'retryable'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 59

def self.openapi_types
  {
    :'code' => :'String',
    :'doc_url' => :'String',
    :'errors' => :'Array<ErrorIssue>',
    :'message' => :'String',
    :'param' => :'String',
    :'retryable' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      doc_url == o.doc_url &&
      errors == o.errors &&
      message == o.message &&
      param == o.param &&
      retryable == o.retryable
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 206

def hash
  [code, doc_url, errors, message, param, retryable].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @retryable.nil?
    invalid_properties.push('invalid value for "retryable", retryable cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
# File 'lib/sendmux_sending_generated/models/error_detail.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @code.nil?
  return false if @message.nil?
  return false if @retryable.nil?
  true
end