Class: Sendmux::Sending::Generated::AttachmentUploadIntentData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Sending::Generated::AttachmentUploadIntentData
- Defined in:
- lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
ISO timestamp when the upload URL expires.
-
#headers ⇒ Object
Headers that must be sent with the PUT upload request.
-
#max_size_bytes ⇒ Object
Maximum upload size in bytes.
-
#method ⇒ Object
HTTP method for upload_url.
-
#upload_id ⇒ Object
Temporary upload intent ID.
-
#upload_url ⇒ Object
Short-lived URL that accepts a binary PUT with the returned headers.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachmentUploadIntentData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AttachmentUploadIntentData
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Sending::Generated::AttachmentUploadIntentData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Sending::Generated::AttachmentUploadIntentData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Hash) self.headers = value end else self.headers = nil end if attributes.key?(:'max_size_bytes') self.max_size_bytes = attributes[:'max_size_bytes'] else self.max_size_bytes = nil end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = nil end if attributes.key?(:'upload_id') self.upload_id = attributes[:'upload_id'] else self.upload_id = nil end if attributes.key?(:'upload_url') self.upload_url = attributes[:'upload_url'] else self.upload_url = nil end end |
Instance Attribute Details
#expires_at ⇒ Object
ISO timestamp when the upload URL expires.
19 20 21 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 19 def expires_at @expires_at end |
#headers ⇒ Object
Headers that must be sent with the PUT upload request.
22 23 24 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 22 def headers @headers end |
#max_size_bytes ⇒ Object
Maximum upload size in bytes
25 26 27 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 25 def max_size_bytes @max_size_bytes end |
#method ⇒ Object
HTTP method for upload_url
28 29 30 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 28 def method @method end |
#upload_id ⇒ Object
Temporary upload intent ID.
31 32 33 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 31 def upload_id @upload_id end |
#upload_url ⇒ Object
Short-lived URL that accepts a binary PUT with the returned headers.
34 35 36 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 34 def upload_url @upload_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 59 def self.attribute_map { :'expires_at' => :'expires_at', :'headers' => :'headers', :'max_size_bytes' => :'max_size_bytes', :'method' => :'method', :'upload_id' => :'upload_id', :'upload_url' => :'upload_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 299 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 81 def self.openapi_types { :'expires_at' => :'Time', :'headers' => :'Hash<String, String>', :'max_size_bytes' => :'Integer', :'method' => :'String', :'upload_id' => :'String', :'upload_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && expires_at == o.expires_at && headers == o.headers && max_size_bytes == o.max_size_bytes && method == o.method && upload_id == o.upload_id && upload_url == o.upload_url end |
#eql?(o) ⇒ Boolean
286 287 288 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 286 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
292 293 294 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 292 def hash [expires_at, headers, max_size_bytes, method, upload_id, upload_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @headers.nil? invalid_properties.push('invalid value for "headers", headers cannot be nil.') end if @max_size_bytes.nil? invalid_properties.push('invalid value for "max_size_bytes", max_size_bytes cannot be nil.') end if @method.nil? invalid_properties.push('invalid value for "method", method cannot be nil.') end if @upload_id.nil? invalid_properties.push('invalid value for "upload_id", upload_id cannot be nil.') end pattern = Regexp.new(/^upl_[a-z0-9]{24}$/) if @upload_id !~ pattern invalid_properties.push("invalid value for \"upload_id\", must conform to the pattern #{pattern}.") end if @upload_url.nil? invalid_properties.push('invalid value for "upload_url", upload_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/sendmux_sending_generated/models/attachment_upload_intent_data.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @expires_at.nil? return false if @headers.nil? return false if @max_size_bytes.nil? return false if @method.nil? method_validator = EnumAttributeValidator.new('String', ["PUT", "unknown_default_open_api"]) return false unless method_validator.valid?(@method) return false if @upload_id.nil? return false if @upload_id !~ Regexp.new(/^upl_[a-z0-9]{24}$/) return false if @upload_url.nil? true end |